@@ -40,9 +40,24 @@ impl IndexBuilder for MysqlQueryBuilder {
             table.prepare(sql, '`');
         }
     }
-}
+    fn prepare_index_type(&self, col_index_type: &Option<IndexType>, sql: &mut SqlWriter) {
+        if let Some(index_type) = col_index_type {
+            if !matches!(index_type, IndexType::FullText) {
+                write!(
+                    sql,
+                    " USING {}",
+                    match index_type {
+                        IndexType::BTree => "BTREE".to_owned(),
+                        IndexType::FullText => unreachable!(),
+                        IndexType::Hash => "HASH".to_owned(),
+                        IndexType::Custom(custom) => custom.to_string(),
+                    }
+                )
+                .unwrap();
+            }
+        }
+    }
 
-impl MysqlQueryBuilder {
     fn prepare_index_prefix(&self, create: &IndexCreateStatement, sql: &mut SqlWriter) {
         if create.primary {
             write!(sql, "PRIMARY ").unwrap();
@@ -54,46 +69,4 @@ impl MysqlQueryBuilder {
             write!(sql, "FULLTEXT ").unwrap();
         }
     }
-
-    fn prepare_index_name(&self, name: &Option<String>, sql: &mut SqlWriter) {
-        if let Some(name) = name {
-            write!(sql, "`{}`", name).unwrap();
-        }
-    }
-
-    fn prepare_index_type(&self, col_index_type: &Option<IndexType>, sql: &mut SqlWriter) {
-        if let Some(index_type) = col_index_type {
-            if !matches!(index_type, IndexType::FullText) {
-                write!(sql, " USING {}", match index_type {
-                    IndexType::BTree => "BTREE".to_owned(),
-                    IndexType::FullText => unreachable!(),
-                    IndexType::Hash => "HASH".to_owned(),
-                    IndexType::Custom(custom) => custom.to_string(),
-                }).unwrap();
-            }
-        }
-    }
-
-    fn prepare_index_columns(&self, columns: &[IndexColumn], sql: &mut SqlWriter) {
-        write!(sql, " (").unwrap();
-        columns.iter().fold(true, |first, col| {
-            if !first {
-                write!(sql, ", ").unwrap();
-            }
-            col.name.prepare(sql, '`');
-            if let Some(prefix) = col.prefix {
-                write!(sql, " (").unwrap();
-                write!(sql, "{}", prefix).unwrap();
-                write!(sql, ")").unwrap();
-            }
-            if let Some(order) = &col.order {
-                match order {
-                    IndexOrder::Asc => write!(sql, " ASC").unwrap(),
-                    IndexOrder::Desc => write!(sql, " DESC").unwrap(),
-                }
-            }
-            false
-        });
-        write!(sql, ")").unwrap();
-    }
-}
\ No newline at end of file
+}
