@@ -426,8 +426,7 @@ pub trait QueryBuilder: QuotedBuilder {
         .unwrap();
     }
 
-    /// Translate [`BinOper`] into SQL statement.
-    fn prepare_bin_oper(
+    fn prepare_bin_oper_common(
         &self,
         bin_oper: &BinOper,
         sql: &mut SqlWriter,
@@ -457,11 +456,22 @@ pub trait QueryBuilder: QuotedBuilder {
                 BinOper::Sub => "-",
                 BinOper::Mul => "*",
                 BinOper::Div => "/",
+                _ => unimplemented!(),
             }
         )
         .unwrap();
     }
 
+    /// Translate [`BinOper`] into SQL statement.
+    fn prepare_bin_oper(
+        &self,
+        bin_oper: &BinOper,
+        sql: &mut SqlWriter,
+        collector: &mut dyn FnMut(Value),
+    ) {
+        self.prepare_bin_oper_common(bin_oper, sql, collector);
+    }
+
     /// Translate [`LogicalChainOper`] into SQL statement.
     fn prepare_logical_chain_oper(
         &self,
@@ -495,7 +505,7 @@ pub trait QueryBuilder: QuotedBuilder {
     }
 
     /// Translate [`Function`] into SQL statement.
-    fn prepare_function(
+    fn prepare_function_common(
         &self,
         function: &Function,
         sql: &mut SqlWriter,
@@ -516,12 +526,23 @@ pub trait QueryBuilder: QuotedBuilder {
                     Function::IfNull => self.if_null_function(),
                     Function::CharLength => self.char_length_function(),
                     Function::Custom(_) => "",
+                    #[cfg(feature = "backend-postgres")]
+                    Function::PgFunction(_) => unimplemented!(),
                 }
             )
             .unwrap();
         }
     }
 
+    fn prepare_function(
+        &self,
+        function: &Function,
+        sql: &mut SqlWriter,
+        collector: &mut dyn FnMut(Value),
+    ) {
+        self.prepare_function_common(function, sql, collector)
+    }
+
     /// Translate [`JoinType`] into SQL statement.
     fn prepare_join_type(
         &self,
