@@ -144,8 +144,8 @@ impl TableCreateStatement {
     }
 
     /// Add a new table column
-    pub fn col(&mut self, column: ColumnDef) -> &mut Self {
-        let mut column = column;
+    pub fn col(&mut self, column: &mut ColumnDef) -> &mut Self {
+        let mut column = column.take();
         column.table = self.table.clone();
         self.columns.push(column);
         self
@@ -177,8 +177,8 @@ impl TableCreateStatement {
     ///     ].join(" ")
     /// );
     /// ```
-    pub fn index(&mut self, index: IndexCreateStatement) -> &mut Self {
-        self.indexes.push(index);
+    pub fn index(&mut self, index: &mut IndexCreateStatement) -> &mut Self {
+        self.indexes.push(index.take());
         self
     }
 
@@ -227,16 +227,16 @@ impl TableCreateStatement {
     ///     ].join(" ")
     /// );
     /// ```
-    pub fn primary_key(&mut self, index: IndexCreateStatement) -> &mut Self {
-        let mut index = index;
+    pub fn primary_key(&mut self, index: &mut IndexCreateStatement) -> &mut Self {
+        let mut index = index.take();
         index.primary = true;
         self.indexes.push(index);
         self
     }
 
     /// Add a foreign key
-    pub fn foreign_key(&mut self, foreign_key: ForeignKeyCreateStatement) -> &mut Self {
-        self.foreign_keys.push(foreign_key);
+    pub fn foreign_key(&mut self, foreign_key: &mut ForeignKeyCreateStatement) -> &mut Self {
+        self.foreign_keys.push(foreign_key.take());
         self
     }
 
@@ -284,6 +284,18 @@ impl TableCreateStatement {
     pub fn get_indexes(&self) -> &Vec<IndexCreateStatement> {
         self.indexes.as_ref()
     }
+
+    pub fn take(&mut self) -> Self {
+        Self {
+            table: self.table.take(),
+            columns: std::mem::replace(&mut self.columns, Vec::new()),
+            options: std::mem::replace(&mut self.options, Vec::new()),
+            partitions: std::mem::replace(&mut self.partitions, Vec::new()),
+            indexes: std::mem::replace(&mut self.indexes, Vec::new()),
+            foreign_keys: std::mem::replace(&mut self.foreign_keys, Vec::new()),
+            if_not_exists: self.if_not_exists,
+        }
+    }
 }
 
 impl SchemaStatementBuilder for TableCreateStatement {
